@@ -71,8 +71,7 @@ class DisconnectRequest(KNXIPBody):
     def __str__(self) -> str:
         """Return object as readable string."""
         return (
-            '<DisconnectRequest CommunicationChannelID="{}" '
-            'control_endpoint="{}" />'.format(
-                self.communication_channel_id, self.control_endpoint
-            )
+            "<DisconnectRequest "
+            f'CommunicationChannelID="{self.communication_channel_id}" '
+            f'control_endpoint="{self.control_endpoint}" />'
         )
