@@ -3,56 +3,77 @@ AddressFilter provides a mechanism for filtering KNX addresses with patterns.
 
 Patterns can be
 
-    for level3 KNX addresses:
+    for level3 KNX group addresses:
 
         AddressFilter("1/*/2-5")
         AddressFilter("1/1-3,4,5/*")
         AddressFilter("1/2/-10)
 
-    for level2 KNX addresses:
+    for level2 KNX group addresses:
 
         AddressFilter("*/2-5")
         AddressFilter("1-3,4,5/*")
         AddressFilter("2/-10")
 
-    for free format KNX addresses:
+    for free format KNX group addresses:
 
         AddressFilter("2-5")
         AddressFilter("1-3,4,5")
         AddressFilter("-10")
+
+    for xknx internal group addresses:
+
+        AddressFilter("i-test")
+        AddressFilter("i-t?st")
+        AddressFilter("i-t*t")
 """
-from typing import List, Tuple, Union
+from __future__ import annotations
+
+from fnmatch import fnmatch
 
 from xknx.exceptions import ConversionError
 
-from .address import GroupAddress
+from .address import GroupAddress, InternalGroupAddress, parse_device_group_address
 
 
 class AddressFilter:
     """Class for filtering Addresses according to patterns."""
 
-    # pylint: disable=too-few-public-methods
-
     def __init__(self, pattern: str) -> None:
         """Initialize AddressFilter class."""
-        self.level_filters: List["AddressFilter.LevelFilter"] = []
+        self.level_filters: list[AddressFilter.LevelFilter] = []
+        self.internal_group_address_pattern: str | None = None
         self._parse_pattern(pattern)
 
     def _parse_pattern(self, pattern: str) -> None:
+        if pattern.startswith("i"):
+            self.internal_group_address_pattern = InternalGroupAddress(pattern).address
+            return
+
         for part in pattern.split("/"):
             self.level_filters.append(AddressFilter.LevelFilter(part))
         if len(self.level_filters) > 3:
             raise ConversionError("Too many parts within pattern.", pattern=pattern)
 
-    def match(self, address: Union[str, GroupAddress]) -> bool:
+    def match(self, address: str | GroupAddress | InternalGroupAddress) -> bool:
         """Test if provided address matches Addressfilter."""
         if isinstance(address, str):
-            address = GroupAddress(address)
-        if len(self.level_filters) == 3:
-            return self._match_level3(address)
-        if len(self.level_filters) == 2:
-            return self._match_level2(address)
-        return self._match_free(address)
+            address = parse_device_group_address(address)
+
+        if isinstance(address, GroupAddress) and self.level_filters:
+            if len(self.level_filters) == 3:
+                return self._match_level3(address)
+            if len(self.level_filters) == 2:
+                return self._match_level2(address)
+            return self._match_free(address)
+
+        if (
+            isinstance(address, InternalGroupAddress)
+            and self.internal_group_address_pattern
+        ):
+            return fnmatch(address.address, self.internal_group_address_pattern)
+
+        return False
 
     def _match_level3(self, address: GroupAddress) -> bool:
         if address.main is None or address.middle is None:
@@ -124,7 +145,7 @@ class AddressFilter:
             if self.range_from > self.range_to:
                 self.range_to, self.range_from = self.range_from, self.range_to
 
-        def get_range(self) -> Tuple[int, int]:
+        def get_range(self) -> tuple[int, int]:
             """Return the range (from,to) of this pattern."""
             return self.range_from, self.range_to
 
@@ -135,10 +156,9 @@ class AddressFilter:
     class LevelFilter:
         """Class for filtering patterns like "8,11-14,20"."""
 
-        # pylint: disable=too-few-public-methods
         def __init__(self, pattern: str) -> None:
             """Initialize LevelFilter."""
-            self.ranges: List["AddressFilter.Range"] = []
+            self.ranges: list[AddressFilter.Range] = []
             self._parse_pattern(pattern)
 
         def _parse_pattern(self, pattern: str) -> None:
